@@ -95,7 +95,6 @@ class OpTest(TestBase):
                         nullable=False)
         context.assert_('ALTER TABLE tests ALTER COLUMN col BIT NOT NULL')
 
-    @config.requirements.fail_before_sqla_084
     def test_drop_index(self):
         context = op_fixture('mssql')
         op.drop_index('my_idx', 'my_table')
@@ -109,6 +108,15 @@ class OpTest(TestBase):
             "exec('alter table t1 drop constraint ' + @const_name)")
         context.assert_contains("ALTER TABLE t1 DROP COLUMN c1")
 
+    def test_drop_column_w_default_in_batch(self):
+        context = op_fixture('mssql')
+        with op.batch_alter_table('t1', schema=None) as batch_op:
+            batch_op.drop_column('c1', mssql_drop_default=True)
+            batch_op.drop_column('c2', mssql_drop_default=True)
+        context.assert_contains(
+            "exec('alter table t1 drop constraint ' + @const_name)")
+        context.assert_contains("ALTER TABLE t1 DROP COLUMN c1")
+
     def test_alter_column_drop_default(self):
         context = op_fixture('mssql')
         op.alter_column("t", "c", server_default=None)
@@ -133,6 +141,15 @@ class OpTest(TestBase):
             "exec('alter table t1 drop constraint ' + @const_name)")
         context.assert_contains("ALTER TABLE t1 DROP COLUMN c1")
 
+    def test_drop_column_w_check_in_batch(self):
+        context = op_fixture('mssql')
+        with op.batch_alter_table('t1', schema=None) as batch_op:
+            batch_op.drop_column('c1', mssql_drop_check=True)
+            batch_op.drop_column('c2', mssql_drop_check=True)
+        context.assert_contains(
+            "exec('alter table t1 drop constraint ' + @const_name)")
+        context.assert_contains("ALTER TABLE t1 DROP COLUMN c1")
+
     def test_drop_column_w_check_quoting(self):
         context = op_fixture('mssql')
         op.drop_column('table', 'column', mssql_drop_check=True)
@@ -154,6 +171,14 @@ class OpTest(TestBase):
             "exec('alter table t1 drop constraint ' + @const_name)")
         context.assert_contains("ALTER TABLE t1 DROP COLUMN c1")
 
+    def test_drop_column_w_fk_in_batch(self):
+        context = op_fixture('mssql')
+        with op.batch_alter_table('t1', schema=None) as batch_op:
+            batch_op.drop_column('c1', mssql_drop_foreign_key=True)
+        context.assert_contains(
+            "exec('alter table t1 drop constraint ' + @const_name)")
+        context.assert_contains("ALTER TABLE t1 DROP COLUMN c1")
+
     def test_alter_column_not_nullable_w_existing_type(self):
         context = op_fixture('mssql')
         op.alter_column("t", "c", nullable=False, existing_type=Integer)
@@ -223,10 +248,39 @@ class OpTest(TestBase):
         op.rename_table('t1', 't2')
         context.assert_contains("EXEC sp_rename 't1', t2")
 
-    # TODO: when we add schema support
-    # def test_alter_column_rename_mssql_schema(self):
-    #    context = op_fixture('mssql')
-    #    op.alter_column("t", "c", name="x", schema="y")
-    #    context.assert_(
-    #        "EXEC sp_rename 'y.t.c', 'x', 'COLUMN'"
-    #    )
+    def test_rename_table_schema(self):
+        context = op_fixture('mssql')
+        op.rename_table('t1', 't2', schema="foobar")
+        context.assert_contains("EXEC sp_rename 'foobar.t1', t2")
+
+    def test_rename_table_casesens(self):
+        context = op_fixture('mssql')
+        op.rename_table('TeeOne', 'TeeTwo')
+        # yup, ran this in SQL Server 2014, the two levels of quoting
+        # seems to be understood.  Can't do the two levels on the
+        # target name though !
+        context.assert_contains("EXEC sp_rename '[TeeOne]', [TeeTwo]")
+
+    def test_rename_table_schema_casesens(self):
+        context = op_fixture('mssql')
+        op.rename_table('TeeOne', 'TeeTwo', schema="FooBar")
+        # yup, ran this in SQL Server 2014, the two levels of quoting
+        # seems to be understood.  Can't do the two levels on the
+        # target name though !
+        context.assert_contains("EXEC sp_rename '[FooBar].[TeeOne]', [TeeTwo]")
+
+    def test_alter_column_rename_mssql_schema(self):
+        context = op_fixture('mssql')
+        op.alter_column("t", "c", name="x", schema="y")
+        context.assert_(
+            "EXEC sp_rename 'y.t.c', x, 'COLUMN'"
+        )
+
+    def test_create_index_mssql_include(self):
+        context = op_fixture('mssql')
+        op.create_index(
+            op.f('ix_mytable_a_b'), 'mytable', ['col_a', 'col_b'],
+            unique=False, mssql_include=['col_c'])
+        context.assert_contains(
+            "CREATE INDEX ix_mytable_a_b ON mytable "
+            "(col_a, col_b) INCLUDE (col_c)")
